==> compose-flow-3.4.0.tar.gz: compose-flow-3.4.0/src/tests/test_backends.py <==
from unittest import TestCase, mock

from compose_flow.environment.backends import get_backend


@mock.patch('compose_flow.environment.backends.local_backend.open')
@mock.patch('compose_flow.environment.backends.local_backend.os')
class LocalBackendTestCase(TestCase):
    buf = 'FOO=1\n'

    @property
    def backend(self):
        backend = get_backend('local')

        return backend

    def _setup_mocks(self, *mocks):
        open_mock = mocks[-1]
        open_mock.return_value.__enter__.return_value.read.return_value = self.buf

        os_mock = mocks[-2]
        os_mock.listdir.return_value = ['foo']

    def test_list(self, *mocks):
        self._setup_mocks(*mocks)

        self.assertEqual(self.backend.list_configs(), ['foo'])

    def test_read(self, *mocks):
        self._setup_mocks(*mocks)

        self.assertEqual(self.backend.read('foo'), self.buf)

    def test_write(self, *mocks):
        self._setup_mocks(*mocks)

        self.backend.write('foo', '/path/to/config')

        open_mock = mocks[-1]

        open_mock.return_value.__enter__.return_value.write.assert_called_with(self.buf)


@mock.patch('compose_flow.environment.backends.swarm_backend.docker')
class SwarmBackendTestCase(TestCase):
    buf = 'FOO=1\n'

    @property
    def backend(self):
        backend = get_backend('swarm')

        return backend

    def _setup_mocks(self, *mocks):
        self.docker_mock = mocks[-1]

    def test_list(self, *mocks):
        self._setup_mocks(*mocks)

        self.backend.list_configs()

        self.docker_mock.get_configs.assert_called()

    def test_read(self, *mocks):
        self._setup_mocks(*mocks)

        name = 'foo'

        self.backend.read(name)

        self.docker_mock.get_config.assert_called_with(name)

    def test_write(self, *mocks):
        self._setup_mocks(*mocks)

        name = 'foo'
        path = '/path/to/config'

        self.backend.write(name, path)

        self.docker_mock.load_config.assert_called_with(name, path)

==> compose-flow-3.5.3.tar.gz: compose-flow-3.5.3/src/tests/test_backends.py <==
from unittest import TestCase, mock

from compose_flow.environment.backends import get_backend


@mock.patch('compose_flow.environment.backends.local_backend.open')
@mock.patch('compose_flow.environment.backends.local_backend.os')
class LocalBackendTestCase(TestCase):
    buf = 'FOO=1\n'

    @property
    def backend(self):
        backend = get_backend('local')

        return backend

    def _setup_mocks(self, *mocks):
        open_mock = mocks[-1]
        open_mock.return_value.__enter__.return_value.read.return_value = self.buf

        os_mock = mocks[-2]
        os_mock.listdir.return_value = ['foo']

    def test_list(self, *mocks):
        self._setup_mocks(*mocks)

        self.assertEqual(self.backend.ls(), ['foo'])

    def test_read(self, *mocks):
        self._setup_mocks(*mocks)

        self.assertEqual(self.backend.read('foo'), self.buf)

    def test_write(self, *mocks):
        self._setup_mocks(*mocks)

        self.backend.write('foo', '/path/to/config')

        open_mock = mocks[-1]

        open_mock.return_value.__enter__.return_value.write.assert_called_with(self.buf)


@mock.patch('compose_flow.environment.backends.swarm_backend.docker')
class SwarmBackendTestCase(TestCase):
    buf = 'FOO=1\n'

    @property
    def backend(self):
        backend = get_backend('swarm')

        return backend

    def _setup_mocks(self, *mocks):
        self.docker_mock = mocks[-1]

    def test_list(self, *mocks):
        self._setup_mocks(*mocks)

        self.backend.ls()

        self.docker_mock.get_configs.assert_called()

    def test_read(self, *mocks):
        self._setup_mocks(*mocks)

        name = 'foo'

        self.backend.read(name)

        self.docker_mock.get_config.assert_called_with(name)

    def test_write(self, *mocks):
        self._setup_mocks(*mocks)

        name = 'foo'
        path = '/path/to/config'

        self.backend.write(name, path)

        self.docker_mock.load_config.assert_called_with(name, path)
